@@ -107,12 +107,8 @@ void ShibLoginDialog::onNewCookieCreated(const QUrl& url, const QNetworkCookie&
             return;
         }
         cookie_seen_ = true;
-        if (!seafApplet->accountManager()->setCurrentAccount(account)) {
-            seafApplet->warningBox(tr("Failed to save current account"), this);
-            reject();
-        } else {
-            accept();
-        }
+        seafApplet->accountManager()->setCurrentAccount(account);
+        accept();
     }
 }
 
